# Hoop!! Yeniden hata oldu...

Beklenmeyen bir hata gerçekleşti. Hata raporu göndermek ister misiniz? Hata raporu otomatik olarak gönderilir ve gelecekte benzer problemlerle karşılaşmanızı engeller.

[Hata mesajı gönder](opensesame://event.bug_report_send){: .important-button}

Gizlilik:

- Aşağıdaki hata mesajı kullanıcı adınız gibi sizi tanımlayabilen bilgiler içerebilir. Eğer içeriyorsa bu bilgiler hatayı düzeltmek dışında başka bir amaç için kullanılmayacaktır.

Bilgi:

- İşletim sistemi: %(platform)s
- OpenSesame: %(version)s
- Python: %(python_version)s

Bu mesajı gösterme!

- Eğer gelecekte hata raporu mesajlarını görmek istemiyorsanız, Menü → Araçlar → Eklenti ve uzantı yöneticisi menüsünü izleyerek bug_report eklentisini etkisiz hale getirebilirsiniz. Bunu yapmanız problemi çözmez, sadece hata raporu göndermeyi durdurur.

Hata mesajları:

%(traceback)s
